# spacefinder


[![image](https://img.shields.io/pypi/v/spacefinder.svg)](https://pypi.python.org/pypi/spacefinder)
[![image](https://img.shields.io/conda/vn/conda-forge/spacefinder.svg)](https://anaconda.org/conda-forge/spacefinder)


**Python Boilerplate contains all the boilerplate you need to create a Python package.**


-   Free software: GNU General Public License v3
-   Documentation: https://TJHomer.github.io/spacefinder
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
